@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2009-2014, Arvid Norberg
+Copyright (c) 2009-2016, Arvid Norberg
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -55,9 +55,7 @@ namespace libtorrent
 	// session. The key fields when adding a torrent are:
 	//
 	// * ti - when you have a .torrent file
-	// * url - when you have a magnet link or http URL to the .torrent file
-	// * info_hash - when all you have is an info-hash (this is similar to a
-	//   magnet link)
+	// * url - when you have a magnet link
 	//
 	// one of those fields need to be set. Another mandatory field is
 	// ``save_path``. The add_torrent_params object is passed into one of the
@@ -227,7 +225,11 @@ namespace libtorrent
 
 			// defaults to off and specifies whether tracker URLs loaded from
 			// resume data should be added to the trackers in the torrent or
-			// replace the trackers.
+			// replace the trackers. When replacing trackers (i.e. this flag is not
+			// set), any trackers passed in via add_torrent_params are also
+			// replaced by any trackers in the resume data. The default behavior is
+			// to have the resume data override the .torrent file _and_ the
+			// trackers added in add_torrent_params.
 			flag_merge_resume_trackers = 0x100,
 
 			// on by default and means that this torrent will be part of state
@@ -250,6 +252,16 @@ namespace libtorrent
 			// case the save_path specified in add_torrent_params is always used.
 			flag_use_resume_save_path = 0x1000,
 
+			// defaults to off and specifies whether web seed URLs loaded from
+			// resume data should be added to the ones in the torrent file or
+			// replace them. No distinction is made between the two different kinds
+			// of web seeds (`BEP 17`_ and `BEP 19`_). When replacing web seeds
+			// (i.e. when this flag is not set), any web seeds passed in via
+			// add_torrent_params are also replaced. The default behavior is to
+			// have any web seeds in the resume data take presedence over whatever
+			// is passed in here as well as the .torrent file.
+			flag_merge_resume_http_seeds = 0x2000,
+
 			// internal
 			default_flags = flag_update_subscribe | flag_auto_managed | flag_paused | flag_apply_ip_filter
 #ifndef TORRENT_NO_DEPRECATE
@@ -339,15 +351,7 @@ namespace libtorrent
 		// ``downloading_metadata`` state until the .torrent file has been
 		// downloaded. If there's any error while downloading, the torrent will
 		// be stopped and the torrent error state (``torrent_status::error``)
-		// will indicate what went wrong. The ``url`` may refer to a magnet link
-		// or a regular http URL.
-		// 
-		// If it refers to an HTTP URL, the info-hash for the added torrent will
-		// not be the true info-hash of the .torrent. Instead a placeholder,
-		// unique, info-hash is used which is later updated once the .torrent
-		// file has been downloaded.
-		// 
-		// Once the info-hash change happens, a torrent_update_alert is posted.
+		// will indicate what went wrong.
 		std::string url;
 
 		// if ``uuid`` is specified, it is used to find duplicates. If another
